==> nextcloud-app-calendar-1:5.5.4-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/calendar/l10n/th.js <==
OC.L10N.register(
    "calendar",
    {
    "Provided email-address is not valid" : "ที่อยู่อีเมลที่ระบุไว้ไม่ถูกต้อง",
    "%s has published the calendar »%s«" : "%s ได้เผยแพร่ปฏิทิน »%s«",
    "Unexpected error sending email. Please contact your administrator." : "เกิดข้อผิดพลาดไม่คาดคิดขณะส่งอีเมล โปรดติดต่อผู้ดูแลระบบของคุณ",
    "Successfully sent email to %1$s" : "ส่งอีเมลถึง %1$s สำเร็จ",
    "Hello," : "สวัสดี",
    "Open »%s«" : "เปิด »%s«",
    "Cheers!" : "ไชโย!",
    "Calendar" : "ปฏิทิน",
    "Confirm" : "ยืนยัน",
    "Location:" : "ตำแหน่ง:",
    "Previous year" : "ปีที่แล้ว",
    "Next year" : "ปีหน้า",
    "Today" : "วันนี้",
    "Day" : "วัน",
    "Week" : "สัปดาห์",
    "Month" : "เดือน",
    "Year" : "ปี",
    "Preview" : "ตัวอย่าง",
    "Copy link" : "คัดลอกลิงก์",
    "Edit" : "แก้ไข",
    "Delete" : "ลบ",
    "Create new" : "สร้างใหม่",
    "Calendars" : "ปฏิทิน",
    "New calendar" : "สร้างปฏิทินใหม่",
    "Export" : "ส่งออก",
    "Empty trash bin" : "ล้างข้อมูลในถังขยะ",
    "Name" : "ชื่อ",
    "Deleted" : "ลบแล้ว",
    "Restore" : "คืนค่า",
    "Delete permanently" : "ลบแบบถาวร",
    "Hidden" : "ซ่อนอยู่",
    "Share link" : "แชร์ลิงก์",
    "can edit" : "สามารถแก้ไข",
    "Share with users or groups" : "แชร์กับผู้ใช้หรือกลุ่ม",
    "Save" : "บันทึก",
    "View" : "มุมมอง",
    "Filename" : "ชื่อไฟล์",
    "Cancel" : "ยกเลิก",
    "Automatic" : "อัตโนมัติ",
    "Year view" : "มุมมองรายปี",
    "List view" : "มุมมองแบบรายการ",
    "Actions" : "การกระทำ",
    "General" : "ทั่วไป",
    "Editing" : "กำลังแก้ไข",
    "Keyboard shortcuts" : "แป้นพิมพ์ลัด",
    "_{duration} year_::_{duration} years_" : ["{duration}ปี"],
    "Update" : "อัปเดต",
    "Location" : "ตำแหน่ง",
    "Description" : "คำอธิบาย",
    "to" : "ถึง",
    "Add" : "เพิ่ม",
    "Monday" : "วันจันทร์",
    "Tuesday" : "วันอังคาร",
    "Wednesday" : "วันพุธ",
    "Thursday" : "วันพฤหัสบดี",
    "Friday" : "วันศุกร์",
    "Saturday" : "วันเสาร์",
    "Sunday" : "วันอาทิตย์",
    "Your email address" : "ที่อยู่อีเมลของคุณ",
    "Notification" : "การแจ้งเตือน",
    "Email" : "อีเมล",
    "seconds" : "วินาที",
    "minutes" : "นาที",
    "hours" : "ชั่วโมง",
    "days" : "วัน",
    "weeks" : "สัปดาห์",
    "Choose a file to add as attachment" : "เลือกไฟล์ที่ต้องการแนบ",
    "Delete file" : "ลบไฟล์",
    "Unknown" : "ไม่ทราบ",
    "Accept" : "ยอมรับ",
    "Decline" : "ปฏิเสธ",
    "Tentative" : "ชั่วคราว",
    "Attendees" : "ผู้เข้าร่วมกิจกรรม",
    "Remove group" : "ลบกลุ่ม",
    "Repeat" : "ทำซ้ำ",
    "never" : "ไม่ต้องเลย",
    "after" : "หลังจาก",
    "Resources" : "ทรัพยากร",
    "Yes" : "ใช่",
    "No" : "ไม่ตกลง",
    "Create" : "สร้าง",
    "Pick a date" : "เลือกวันที่",
    "Global" : "ทั่วไป",
    "Subscribe" : "สมัครรับข้อมูล",
    "Personal" : "ส่วนตัว",
    "Edit event" : "แก้ไขกิจกรรม",
    "Close" : "ปิด",
    "Selected" : "เลือกอยู่",
    "Submit" : "ส่ง",
    "Anniversary" : "วันครบรอบ",
    "Week {number} of {year}" : "สัปดาห์ที่ {number} ของปี {year}",
    "Daily" : "รายวัน",
    "Weekly" : "รายสัปดาห์",
    "Monthly" : "ทุก ๆ เดือน",
    "Yearly" : "ทุก ๆ ปี",
    "second" : "วินาที",
    "Other" : "อื่น ๆ",
    "When shared show full event" : "เมื่อแชร์จะแสดงกิจกรรมเต็ม",
    "When shared show only busy" : "เมื่อแชร์จะแสดงเฉพาะไม่ว่าง",
    "When shared hide this event" : "เมื่อแชร์จะซ่อนกิจกรรมนี้",
    "Status" : "สถานะ",
    "Confirmed" : "ยืนยันแล้ว",
    "Categories" : "หมวดหมู่"
},
"nplurals=1; plural=0;");

==> nextcloud-app-calendar-1:5.5.5-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/calendar/l10n/th.js <==
OC.L10N.register(
    "calendar",
    {
    "Provided email-address is not valid" : "ที่อยู่อีเมลที่ระบุไว้ไม่ถูกต้อง",
    "%s has published the calendar »%s«" : "%s ได้เผยแพร่ปฏิทิน »%s«",
    "Unexpected error sending email. Please contact your administrator." : "เกิดข้อผิดพลาดไม่คาดคิดขณะส่งอีเมล โปรดติดต่อผู้ดูแลระบบของคุณ",
    "Successfully sent email to %1$s" : "ส่งอีเมลถึง %1$s สำเร็จ",
    "Hello," : "สวัสดี",
    "Open »%s«" : "เปิด »%s«",
    "Cheers!" : "ไชโย!",
    "Calendar" : "ปฏิทิน",
    "Confirm" : "ยืนยัน",
    "Location:" : "ตำแหน่ง:",
    "Previous year" : "ปีที่แล้ว",
    "Next year" : "ปีหน้า",
    "Today" : "วันนี้",
    "Day" : "วัน",
    "Week" : "สัปดาห์",
    "Month" : "เดือน",
    "Year" : "ปี",
    "Preview" : "ตัวอย่าง",
    "Copy link" : "คัดลอกลิงก์",
    "Edit" : "แก้ไข",
    "Delete" : "ลบ",
    "Create new" : "สร้างใหม่",
    "Calendars" : "ปฏิทิน",
    "New calendar" : "สร้างปฏิทินใหม่",
    "Export" : "ส่งออก",
    "Empty trash bin" : "ล้างข้อมูลในถังขยะ",
    "Name" : "ชื่อ",
    "Deleted" : "ลบแล้ว",
    "Restore" : "คืนค่า",
    "Delete permanently" : "ลบแบบถาวร",
    "Share link" : "แชร์ลิงก์",
    "can edit" : "สามารถแก้ไข",
    "Share with users or groups" : "แชร์กับผู้ใช้หรือกลุ่ม",
    "Save" : "บันทึก",
    "View" : "มุมมอง",
    "Filename" : "ชื่อไฟล์",
    "Cancel" : "ยกเลิก",
    "Automatic" : "อัตโนมัติ",
    "Year view" : "มุมมองรายปี",
    "List view" : "มุมมองแบบรายการ",
    "Actions" : "การกระทำ",
    "General" : "ทั่วไป",
    "Editing" : "กำลังแก้ไข",
    "Keyboard shortcuts" : "แป้นพิมพ์ลัด",
    "_{duration} year_::_{duration} years_" : ["{duration}ปี"],
    "Update" : "อัปเดต",
    "Location" : "ตำแหน่ง",
    "Description" : "คำอธิบาย",
    "to" : "ถึง",
    "Add" : "เพิ่ม",
    "Monday" : "วันจันทร์",
    "Tuesday" : "วันอังคาร",
    "Wednesday" : "วันพุธ",
    "Thursday" : "วันพฤหัสบดี",
    "Friday" : "วันศุกร์",
    "Saturday" : "วันเสาร์",
    "Sunday" : "วันอาทิตย์",
    "Your email address" : "ที่อยู่อีเมลของคุณ",
    "Notification" : "การแจ้งเตือน",
    "Email" : "อีเมล",
    "seconds" : "วินาที",
    "minutes" : "นาที",
    "hours" : "ชั่วโมง",
    "days" : "วัน",
    "weeks" : "สัปดาห์",
    "Choose a file to add as attachment" : "เลือกไฟล์ที่ต้องการแนบ",
    "Delete file" : "ลบไฟล์",
    "Unknown" : "ไม่ทราบ",
    "Accept" : "ยอมรับ",
    "Decline" : "ปฏิเสธ",
    "Tentative" : "ชั่วคราว",
    "Attendees" : "ผู้เข้าร่วมกิจกรรม",
    "Remove group" : "ลบกลุ่ม",
    "Repeat" : "ทำซ้ำ",
    "never" : "ไม่ต้องเลย",
    "after" : "หลังจาก",
    "Resources" : "ทรัพยากร",
    "Yes" : "ใช่",
    "No" : "ไม่ตกลง",
    "None" : "ไม่มี",
    "Create" : "สร้าง",
    "Pick a date" : "เลือกวันที่",
    "Global" : "ทั่วไป",
    "Subscribe" : "สมัครรับข้อมูล",
    "Personal" : "ส่วนตัว",
    "Edit event" : "แก้ไขกิจกรรม",
    "Close" : "ปิด",
    "Selected" : "เลือกอยู่",
    "Submit" : "ส่ง",
    "Anniversary" : "วันครบรอบ",
    "Week {number} of {year}" : "สัปดาห์ที่ {number} ของปี {year}",
    "Daily" : "รายวัน",
    "Weekly" : "รายสัปดาห์",
    "Monthly" : "ทุก ๆ เดือน",
    "Yearly" : "ทุก ๆ ปี",
    "second" : "วินาที",
    "Other" : "อื่น ๆ",
    "When shared show full event" : "เมื่อแชร์จะแสดงกิจกรรมเต็ม",
    "When shared show only busy" : "เมื่อแชร์จะแสดงเฉพาะไม่ว่าง",
    "When shared hide this event" : "เมื่อแชร์จะซ่อนกิจกรรมนี้",
    "Status" : "สถานะ",
    "Confirmed" : "ยืนยันแล้ว",
    "Categories" : "หมวดหมู่",
    "Hidden" : "ซ่อนอยู่"
},
"nplurals=1; plural=0;");
